Documentation
¶
Index ¶
- Variables
- func RegisterInterfaces(registry codectypes.InterfaceRegistry)
- type Prover
- func (pr *Prover) CheckRefreshRequired(ctx context.Context, dst core.ChainInfoICS02Querier) (bool, error)
- func (pr *Prover) CreateInitialLightClientState(ctx context.Context, height exported.Height) (exported.ClientState, exported.ConsensusState, error)
- func (pr *Prover) GetLatestFinalizedHeader(ctx context.Context) (core.Header, error)
- func (pr *Prover) Init(homePath string, timeout time.Duration, codec codec.ProtoCodecMarshaler, ...) error
- func (pr *Prover) ProveHostConsensusState(ctx core.QueryContext, height exported.Height, ...) ([]byte, error)
- func (pr *Prover) ProveState(ctx core.QueryContext, path string, value []byte) ([]byte, clienttypes.Height, error)
- func (pr *Prover) SetRelayInfo(path *core.PathEnd, counterparty *core.ProvableChain, ...) error
- func (pr *Prover) SetupForRelay(ctx context.Context) error
- func (pr *Prover) SetupHeadersForUpdate(ctx context.Context, counterparty core.FinalityAwareChain, ...) (<-chan *core.HeaderOrError, error)
- type ProverConfig
- func (pc ProverConfig) Build(chain core.Chain) (core.Prover, error)
- func (*ProverConfig) Descriptor() ([]byte, []int)
- func (m *ProverConfig) Marshal() (dAtA []byte, err error)
- func (m *ProverConfig) MarshalTo(dAtA []byte) (int, error)
- func (m *ProverConfig) MarshalToSizedBuffer(dAtA []byte) (int, error)
- func (*ProverConfig) ProtoMessage()
- func (m *ProverConfig) Reset()
- func (m *ProverConfig) Size() (n int)
- func (m *ProverConfig) String() string
- func (m *ProverConfig) Unmarshal(dAtA []byte) error
- func (cfg *ProverConfig) UnpackInterfaces(unpacker codectypes.AnyUnpacker) error
- func (c ProverConfig) Validate() error
- func (m *ProverConfig) XXX_DiscardUnknown()
- func (m *ProverConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ProverConfig) XXX_Merge(src proto.Message)
- func (m *ProverConfig) XXX_Size() int
- func (m *ProverConfig) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
Functions ¶
func RegisterInterfaces ¶
func RegisterInterfaces(registry codectypes.InterfaceRegistry)
RegisterInterfaces register the module interfaces to protobuf Any.
Types ¶
type Prover ¶
func (*Prover) CheckRefreshRequired ¶
func (pr *Prover) CheckRefreshRequired(ctx context.Context, dst core.ChainInfoICS02Querier) (bool, error)
CheckRefreshRequired returns if the on-chain light client needs to be updated.
func (*Prover) CreateInitialLightClientState ¶
func (pr *Prover) CreateInitialLightClientState(ctx context.Context, height exported.Height) (exported.ClientState, exported.ConsensusState, error)
CreateInitialLightClientState creates a pair of ClientState and ConsensusState for building MsgCreateClient submitted to the counterparty chain
func (*Prover) GetLatestFinalizedHeader ¶
GetLatestFinalizedHeader returns the latest finalized header
func (*Prover) ProveHostConsensusState ¶
func (pr *Prover) ProveHostConsensusState(ctx core.QueryContext, height exported.Height, consensusState exported.ConsensusState) ([]byte, error)
ProveHostConsensusState returns the proof of the consensus state at `height`
func (*Prover) ProveState ¶
func (pr *Prover) ProveState(ctx core.QueryContext, path string, value []byte) ([]byte, clienttypes.Height, error)
ProveState returns the proof of an IBC state specified by `path` and `value`
func (*Prover) SetRelayInfo ¶
func (pr *Prover) SetRelayInfo(path *core.PathEnd, counterparty *core.ProvableChain, counterpartyPath *core.PathEnd) error
SetRelayInfo sets source's path and counterparty's info to the chain
func (*Prover) SetupHeadersForUpdate ¶
func (pr *Prover) SetupHeadersForUpdate(ctx context.Context, counterparty core.FinalityAwareChain, latestFinalizedHeader core.Header) (<-chan *core.HeaderOrError, error)
SetupHeadersForUpdate returns the finalized header and any intermediate headers needed to apply it to the client on the counterparty chain
type ProverConfig ¶
type ProverConfig struct {
OriginProver *types.Any `protobuf:"bytes,1,opt,name=origin_prover,json=originProver,proto3" json:"origin_prover,omitempty"`
}
func (*ProverConfig) Descriptor ¶
func (*ProverConfig) Descriptor() ([]byte, []int)
func (*ProverConfig) Marshal ¶
func (m *ProverConfig) Marshal() (dAtA []byte, err error)
func (*ProverConfig) MarshalToSizedBuffer ¶
func (m *ProverConfig) MarshalToSizedBuffer(dAtA []byte) (int, error)
func (*ProverConfig) ProtoMessage ¶
func (*ProverConfig) ProtoMessage()
func (*ProverConfig) Reset ¶
func (m *ProverConfig) Reset()
func (*ProverConfig) Size ¶
func (m *ProverConfig) Size() (n int)
func (*ProverConfig) String ¶
func (m *ProverConfig) String() string
func (*ProverConfig) Unmarshal ¶
func (m *ProverConfig) Unmarshal(dAtA []byte) error
func (*ProverConfig) UnpackInterfaces ¶
func (cfg *ProverConfig) UnpackInterfaces(unpacker codectypes.AnyUnpacker) error
func (ProverConfig) Validate ¶
func (c ProverConfig) Validate() error
func (*ProverConfig) XXX_DiscardUnknown ¶
func (m *ProverConfig) XXX_DiscardUnknown()
func (*ProverConfig) XXX_Marshal ¶
func (m *ProverConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ProverConfig) XXX_Merge ¶
func (m *ProverConfig) XXX_Merge(src proto.Message)
func (*ProverConfig) XXX_Size ¶
func (m *ProverConfig) XXX_Size() int
func (*ProverConfig) XXX_Unmarshal ¶
func (m *ProverConfig) XXX_Unmarshal(b []byte) error